@@ -1,5 +1,3 @@
-from typing import Optional
-
 from .. import Provider as AddressProvider
 
 
@@ -155,7 +153,6 @@ class Provider(AddressProvider):
         "Litouwen",
         "Luxemburg",
         "Macau",
-        "Macedonië",
         "Madagaskar",
         "Malawi",
         "Maldiven",
@@ -189,6 +186,7 @@ class Provider(AddressProvider):
         "Nigeria",
         "Niue",
         "Noord-Korea",
+        "Noord-Macedonië",
         "Noordelijke Marianen",
         "Noorwegen",
         "Norfolk",
@@ -2730,10 +2728,10 @@ class Provider(AddressProvider):
 
     address_formats = ("{{street_address}}\n{{postcode}}\n{{city}}",)
 
-    def administrative_unit(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.provinces, min_length, max_length)
+    def administrative_unit(self) -> str:
+        return self.random_element(self.provinces)
 
     province = administrative_unit
 
-    def city(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.cities, min_length, max_length)
+    def city(self) -> str:
+        return self.random_element(self.cities)
